# frozen_string_literal: true

module API
  class VulnerabilityFindings < Grape::API
    include PaginationParams

    helpers ::API::Helpers::VulnerabilityFindingsHelpers

    before do
      authenticate!
    end

    params do
      requires :id, type: String, desc: 'The ID of a project'
    end

    resource :projects, requirements: API::NAMESPACE_OR_PROJECT_REQUIREMENTS do
      params do
        use :vulnerability_findings_params
      end
      desc 'Get a list of project vulnerability findings' do
        success ::Vulnerabilities::OccurrenceEntity
      end
      get ':id/vulnerability_findings' do
        if Feature.enabled?(:first_class_vulnerabilities)
          respond_with_vulnerability_findings
        else
          not_found!
        end
      end
    end
  end
end
