# frozen_string_literal: true

require 'spec_helper'

describe API::VulnerabilityFindings do
  let_it_be(:project) { create(:project, :public) }
  let_it_be(:user) { create(:user) }

  describe "GET /projects/:id/vulnerability_findings" do
    let(:project_vulnerabilities_path) { "/projects/#{project.id}/vulnerability_findings" }

    it_behaves_like 'getting list of vulnerability findings'
    it_behaves_like 'forbids access to project vulnerabilities endpoint in expected cases'

    context 'with an authorized user with proper permissions' do
      before do
        project.add_developer(user)
      end

      context 'when "first-class vulnerabilities" feature is disabled' do
        before do
          stub_feature_flags(first_class_vulnerabilities: false)
        end

        it 'responds with "not found"' do
          get api(project_vulnerabilities_path, user)

          expect(response).to have_gitlab_http_status(404)
        end
      end
    end
  end
end
